function par = get_palette_parent(pal)

% get_palette_parent - get palette parent
% ---------------------------------------
%
% par = get_palette_parent(pal)
%
% Input:
% ------
%  pal - palette handle
%
% Output:
% -------
%  par - parent handle

%--------------------------------
% Author: Harold Figueroa
%--------------------------------
% $Revision: 3084 $
% $Date: 2005-12-20 18:54:15 -0500 (Tue, 20 Dec 2005) $
%--------------------------------

%--
% check input is palette
%--

if (~is_palette(pal))
	error('Input handle is not a palette.');
end

%--
% get parent data from palette
%--

data = get(pal,'userdata');

if (~isfield(data,'parent'))
	par = []; return;
end

par = data.parent;

% NOTE: at the moment a screen parent is no parent

if (par == 0)
	par = [];
end